![Test and Coverage Measuring](https://github.com/tarc/asyncfileserver/workflows/Test%20and%20Coverage%20Measuring/badge.svg?branch=master) [![codecov](https://codecov.io/gh/tarc/asyncfileserver/branch/master/graph/badge.svg)](https://codecov.io/gh/tarc/asyncfileserver)

# Simple File Server Featuring Python Async Constructs

This is a toy project to excercise the new async facilities from python 3.5+.

This project features [Github Actions](https://github.com/features/actions)
to automate testing, package publishing and even to bump versions and tag
them to the repository.

The package is published to [PyPI](https://pypi.org/) as
[asyncfileserver](https://pypi.org/project/asyncfileserver/). The test
coverage report is provided by [Codecov](https://codecov.io/).